@@ -1,6 +1,6 @@
-from typing import Annotated
+from typing import Final, Literal, get_args
 
-from pydantic import UUID4, Field
+from pydantic import UUID4, TypeAdapter
 
 from mex.common.models import BaseModel
 from mex.common.types import Email
@@ -9,32 +9,22 @@ from mex.common.types import Email
 class LDAPActor(BaseModel):
     """Model class for generic LDAP accounts."""
 
-    sAMAccountName: str | None = None
     objectGUID: UUID4
+    sAMAccountName: str | None = None
     mail: list[Email] = []
 
-    @staticmethod
-    def get_ldap_fields() -> tuple[str, ...]:
-        """Return the fields that should be fetched from LDAP."""
-        return tuple(sorted(LDAPActor.model_fields))
-
 
 class LDAPPerson(LDAPActor):
     """Model class for LDAP persons."""
 
+    employeeID: str
+    givenName: list[str]
+    sn: str
     company: str | None = None
     department: str | None = None
     departmentNumber: str | None = None
     displayName: str | None = None
-    employeeID: str
-    givenName: Annotated[list[str], Field(min_length=1)]
     ou: list[str] = []
-    sn: str
-
-    @classmethod
-    def get_ldap_fields(cls) -> tuple[str, ...]:
-        """Return the fields that should be fetched from LDAP."""
-        return tuple(sorted(cls.model_fields))
 
 
 class LDAPPersonWithQuery(BaseModel):
@@ -44,7 +34,18 @@ class LDAPPersonWithQuery(BaseModel):
     query: str
 
 
-class LDAPUnit(LDAPActor):
-    """Model class for LDAP organizational units."""
+class LDAPFunctionalAccount(LDAPActor):
+    """Model class for LDAP functional accounts."""
 
-    parent_label: str | None = None
+    ou: list[Literal["Funktion"]]
+
+
+AnyLDAPActor = LDAPPerson | LDAPFunctionalAccount
+LDAP_MODEL_CLASSES: Final[list[type[AnyLDAPActor]]] = list(get_args(AnyLDAPActor))
+AnyLDAPActorsTypeAdapter: TypeAdapter[list[AnyLDAPActor]] = TypeAdapter(
+    list[AnyLDAPActor]
+)
+LDAPFunctionalAccountsTypeAdapter: TypeAdapter[list[LDAPFunctionalAccount]] = (
+    TypeAdapter(list[LDAPFunctionalAccount])
+)
+LDAPPersonsTypeAdapter: TypeAdapter[list[LDAPPerson]] = TypeAdapter(list[LDAPPerson])
