@@ -4,11 +4,11 @@ from typing import TypeVar
 from mex.common.exceptions import MExError
 from mex.common.logging import logger
 from mex.common.models import (
+    ExtractedOrganization,
     ExtractedOrganizationalUnit,
     ExtractedPrimarySource,
     MergedOrganizationalUnit,
 )
-from mex.common.models.organization import ExtractedOrganization
 from mex.common.organigram.extract import extract_organigram_units
 from mex.common.organigram.models import OrganigramUnit
 from mex.common.organigram.transform import (
