@@ -5,6 +5,9 @@ class DummyConnector(BaseConnector):
     def __init__(self) -> None:
         self.closed = False
 
+    def metrics(self) -> dict[str, int]:
+        return {"foo": 42}
+
     def close(self) -> None:
         self.closed = True
 
@@ -28,3 +31,13 @@ def test_connector_store_reset() -> None:
 
     assert connector.closed is True
     assert len(list(CONNECTOR_STORE)) == 0
+
+
+def test_connector_store_metrics() -> None:
+    DummyConnector.get()
+    assert len(list(CONNECTOR_STORE)) == 1
+
+    assert CONNECTOR_STORE.metrics() == {"dummy_connector_foo": 42}
+
+    CONNECTOR_STORE.reset()
+    assert CONNECTOR_STORE.metrics() == {}
