@@ -9,7 +9,11 @@ from mex.common.logging import watch
 
 
 def test_watch(caplog: LogCaptureFixture) -> None:
-    items = ["foo", UUID(int=16, version=4), MExError("foo", 42)]
+    items: list[str | UUID | MExError] = [
+        "foo",
+        UUID(int=16, version=4),
+        MExError("foo", 42),
+    ]
 
     @watch(log_interval=1)
     def dummy_generator() -> Generator[str | UUID | MExError, None, None]:
